==> elgg-1.9.2.zip: elgg-1.9.2/mod/bookmarks/languages/nl.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'bookmarks' => "Favorieten",
	'bookmarks:add' => "Favoriet toevoegen",
	'bookmarks:edit' => "Bewerk favoriet",
	'bookmarks:owner' => "%s's favorieten",
	'bookmarks:friends' => "Favorieten van vrienden",
	'bookmarks:everyone' => "Alle Site favorieten",
	'bookmarks:this' => "Voeg favoriet toe",
	'bookmarks:this:group' => "Favoriet in %s",
	'bookmarks:bookmarklet' => "Browser plugin",
	'bookmarks:bookmarklet:group' => "Verkrijg groeps bookmarklet",
	'bookmarks:inbox' => "Favorieten inbox",
	'bookmarks:with' => "Deel met",
	'bookmarks:new' => "Een nieuwe favoriet",
	'bookmarks:address' => "Adres van de favoriet",
	'bookmarks:none' => 'Geen favorieten',

	'bookmarks:notify:summary' => 'Nieuwe favoriet genoemd %s',
	'bookmarks:notify:subject' => 'Nieuwe favoriet: %s',
	'bookmarks:notify:body' =>
'%s voegde een nieuwe favoriet toe: %s

Adres: %s

%s

Bekijk en reageer op de favoriet:
%s
',

	'bookmarks:delete:confirm' => "Weet je zeker dat je deze favoriet wilt verwijderen?",

	'bookmarks:numbertodisplay' => 'Aantal favorieten om weer te geven',

	'bookmarks:shared' => "Favoriet",
	'bookmarks:visit' => "Ga naar de pagina",
	'bookmarks:recent' => "Recente favorieten",

	'river:create:object:bookmarks' => '%s maakte %s aan als favoriet',
	'river:comment:object:bookmarks' => '%s reageerde op een favoriet %s',
	'bookmarks:river:annotate' => 'een reactie op deze favoriet',
	'bookmarks:river:item' => 'een favoriet',

	'item:object:bookmarks' => 'Favorieten',

	'bookmarks:group' => 'Groeps favorieten',
	'bookmarks:enablebookmarks' => 'Schakel groeps favorieten in',
	'bookmarks:nogroup' => 'Deze groep heeft nog geen favorieten',
	
	/**
	 * Widget and bookmarklet
	 */
	'bookmarks:widget:description' => "Deze widget is ontworpen voor je Dashboard en laat je de laatste favorieten in de Inbox zien.",

	'bookmarks:bookmarklet:description' =>
			"De favorieten Browser plugin maakt het mogelijk om iedere willekeurige pagina te delen met je vrienden, of om gewoon voor jezelf om te onthouden. Om het te gebruiken sleep je de Browser plugin naar je Links balk van je browser: ",

	'bookmarks:bookmarklet:descriptionie' =>
			"Als je Internet Explorer gebruikt moet je met de rechter muisknop op de Browser plugin klikken en dan kiezen voor 'toevoegen aan favorieten' en dan de Links balk.",

	'bookmarks:bookmarklet:description:conclusion' =>
			"Je kunt dan iedere pagina die je bezoekt markeren door op de link te klikken.",

	/**
	 * Status messages
	 */

	'bookmarks:save:success' => "Je favoriet is succesvol opgeslagen.",
	'bookmarks:delete:success' => "Je favoriet is succesvol verwijderd.",

	/**
	 * Error messages
	 */

	'bookmarks:save:failed' => "Je favoriet kon niet worden opgeslagen. Probeer het nogmaals.",
	'bookmarks:save:invalid' => "Het adres van de favoriet is ongeldig en kon niet worden opgeslagen.",
	'bookmarks:delete:failed' => "Je favoriet kon niet worden verwijderd. Probeer het nogmaals.",
	'bookmarks:unknown_bookmark' => 'Kan deze favoriet niet vinden',
);

==> elgg-1.11.0.zip: elgg-1.11.0/mod/bookmarks/languages/nl.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'bookmarks' => "Favorieten",
	'bookmarks:add' => "Favoriet toevoegen",
	'bookmarks:edit' => "Bewerk favoriet",
	'bookmarks:owner' => "Favorieten van %s",
	'bookmarks:friends' => "Favorieten van vrienden",
	'bookmarks:everyone' => "Alle sitefavorieten",
	'bookmarks:this' => "Voeg favoriet toe",
	'bookmarks:this:group' => "Favoriet in '%s'",
	'bookmarks:bookmarklet' => "Browser-plugin",
	'bookmarks:bookmarklet:group' => "Verkrijg groeps-bookmarklet",
	'bookmarks:inbox' => "Favorieteninbox",
	'bookmarks:with' => "Deel met",
	'bookmarks:new' => "Een nieuwe favoriet",
	'bookmarks:address' => "Adres van de favoriet",
	'bookmarks:none' => 'Geen favorieten',

	'bookmarks:notify:summary' => 'Nieuwe favoriet genaamd \'%s\'',
	'bookmarks:notify:subject' => 'Nieuwe favoriet: %s',
	'bookmarks:notify:body' =>
'Hallo!

%s voegde een nieuwe favoriet toe: %s

De favoriet kun je hier vinden: %s

%s

Hier kun je de favoriet bekijken en erop reageren: 
%s

----

Dit is een automatisch aangemaakt bericht. Je kunt hier niet op antwoorden.',

	'bookmarks:delete:confirm' => "Weet je zeker dat je deze favoriet wilt verwijderen?",

	'bookmarks:numbertodisplay' => 'Aantal favorieten om weer te geven',

	'bookmarks:shared' => "Favoriet",
	'bookmarks:visit' => "Ga naar de pagina",
	'bookmarks:recent' => "Recente favorieten",

	'river:create:object:bookmarks' => '%s maakte %s aan als favoriet',
	'river:comment:object:bookmarks' => '%s reageerde op een favoriet %s',
	'bookmarks:river:annotate' => 'een reactie op deze favoriet',
	'bookmarks:river:item' => 'een favoriet',

	'item:object:bookmarks' => 'Favorieten',

	'bookmarks:group' => 'Groepsfavorieten',
	'bookmarks:enablebookmarks' => 'Schakel groepsfavorieten in',
	'bookmarks:nogroup' => 'Deze groep heeft nog geen favorieten',
	
	/**
	 * Widget and bookmarklet
	 */
	'bookmarks:widget:description' => "Deze widget is ontworpen voor je Dashboard en laat je de laatste favorieten in de Inbox zien.",

	'bookmarks:bookmarklet:description' =>
			"De favorieten browser-plugin maakt het mogelijk om iedere willekeurige pagina te delen met je vrienden, of om gewoon voor jezelf om te onthouden. Om hem te gebruiken sleep je de browser-plugin naar de favorietenbalk van je browser (deze kan ook de bladwijzerbalk heten):",

	'bookmarks:bookmarklet:descriptionie' =>
			"Als je Internet Explorer gebruikt moet je met de rechter muisknop op de browser-plugin klikken. Kies daarna voor 'toevoegen aan favorieten', en vervolgens de \"Links-balk\".",

	'bookmarks:bookmarklet:description:conclusion' =>
			"Je kunt dan iedere pagina die je bezoekt markeren door op de link te klikken.",

	/**
	 * Status messages
	 */

	'bookmarks:save:success' => "Je favoriet is succesvol opgeslagen.",
	'bookmarks:delete:success' => "Je favoriet is succesvol verwijderd.",

	/**
	 * Error messages
	 */

	'bookmarks:save:failed' => "Je favoriet kon niet worden opgeslagen. Probeer het nogmaals.",
	'bookmarks:save:invalid' => "Het adres van de favoriet is ongeldig en kon niet worden opgeslagen.",
	'bookmarks:delete:failed' => "Je favoriet kon niet worden verwijderd. Probeer het nogmaals.",
	'bookmarks:unknown_bookmark' => 'Kan deze favoriet niet vinden',
);
